@@ -147,7 +147,7 @@ EOF
 		;;
 
 		sgdisk)
-			$SGDISK_BIN $TEMP_DISK -${OPT_NEW}=1 -${OPT_CHANGE_NAME}=1:"${TEST_PART_DEFAULT_NAME}"
+			$SGDISK_BIN $TEMP_DISK -${OPT_NEW} 1 -${OPT_CHANGE_NAME} 1:"${TEST_PART_DEFAULT_NAME}"
 		;;
 	esac
 
@@ -171,7 +171,7 @@ EOF
 		;;
 
 		sgdisk)
-			$SGDISK_BIN $TEMP_DISK -${OPT_CHANGE_NAME}=1:${TEST_PART_NEWNAME}
+			$SGDISK_BIN $TEMP_DISK -${OPT_CHANGE_NAME} 1:${TEST_PART_NEWNAME}
 		;;
 	esac
 
@@ -195,7 +195,7 @@ EOF
 		;;
 
 		sgdisk)
-			$SGDISK_BIN $TEMP_DISK -${OPT_CHANGE_TYPE}=1:${TEST_PART_NEWTYPE}
+			$SGDISK_BIN $TEMP_DISK -${OPT_CHANGE_TYPE} 1:${TEST_PART_NEWTYPE}
 		;;
 	esac
 
@@ -219,7 +219,7 @@ echo ""
 		;;
 
 		sgdisk)
-			$SGDISK_BIN $TEMP_DISK -${OPT_BACKUP}=${GPT_BACKUP_FILENAME}
+			$SGDISK_BIN $TEMP_DISK -${OPT_BACKUP} ${GPT_BACKUP_FILENAME}
 		;;
 	esac
 
@@ -248,7 +248,7 @@ EOF
 		;;
 
 		sgdisk)
-			$SGDISK_BIN $TEMP_DISK -${OPT_DELETE}=1
+			$SGDISK_BIN $TEMP_DISK -${OPT_DELETE} 1
 		;;
 	esac
 
